"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDebugLcfConfig = exports.getProdLcfConfig = void 0;
const toolbox_1 = require("@cloudbase/toolbox");
function getProdLibConfig(lib, configType) {
    if (configType === 'components') {
        switch (lib.name) {
            case 'gsd-h5-react': {
                const baseInfo = {
                    name: lib.name,
                    type: 'local',
                    referenceRule: '$module/$componentPath',
                    tagRenameRule: '$component',
                    downloadUrl: lib.mpPkgUrl,
                    isBareDir: true,
                };
                return baseInfo;
            }
            case 'CLOUDBASE_STANDARD': {
                const baseInfo = {
                    name: lib.name,
                    type: 'local',
                    referenceRule: '$module/$component/index',
                    tagRenameRule: 'TCB-$component',
                    compileFromSource: true,
                    sourceData: lib.components,
                    isBareDir: true,
                };
                return baseInfo;
            }
            default: {
                const baseInfo = {
                    name: lib.name,
                    type: 'local',
                    referenceRule: '$module/src/$componentPath',
                    tagRenameRule: '$component',
                    downloadUrl: lib.mpPkgUrl,
                    isBareDir: true,
                };
                return baseInfo;
            }
        }
    }
    else if (configType === 'actions') {
        switch (lib.name) {
            case 'gsd-h5-react': {
                const baseInfo = {
                    name: lib.name,
                    type: 'local',
                    referenceRule: '$module/actions/$feature/index',
                    exportType: 'default',
                    downloadUrl: lib.mpPkgUrl,
                    isBareDir: true,
                };
                return baseInfo;
            }
            default: {
                const baseInfo = {
                    name: lib.name,
                    type: 'local',
                    referenceRule: '$module/src/actions/$feature/index',
                    exportType: 'default',
                    downloadUrl: lib.mpPkgUrl,
                    isBareDir: true,
                };
                return baseInfo;
            }
        }
    }
    else {
        throw new toolbox_1.CloudBaseError(`不能识别的组件类型: ${configType}`);
    }
}
function getProdLcfConfig(libs, projectPath) {
    const options = {
        // 开启兼容模式，兼容WeApps特性和组件库
        compatibleMode: true,
        // 组件库配置
        componentsLibs: libs.map((lib) => getProdLibConfig(lib, 'components')),
        // 工具库配置
        materialLibs: libs.filter((lib) => !lib.isComposite).map((lib) => getProdLibConfig(lib, 'actions')),
        // 输出路径
        output: {
            path: projectPath,
        },
    };
    return options;
}
exports.getProdLcfConfig = getProdLcfConfig;
function getDebugLcfConfig(libs, projectPath, port) {
    const options = {
        // 开启兼容模式，兼容WeApps特性和组件库
        compatibleMode: true,
        // 组件库配置
        componentsLibs: libs.map((lib) => {
            const baseInfo = {
                name: lib.name,
                type: 'local',
                referenceRule: '$module/src/$componentPath',
                tagRenameRule: `${lib.name}-$component`,
                downloadUrl: `http://127.0.0.1:${port}/assets/${lib.name}.zip`,
                isBareDir: true,
            };
            return baseInfo;
        }),
        // 工具库配置
        materialLibs: libs.map((lib) => {
            const baseInfo = {
                name: lib.name,
                type: 'local',
                referenceRule: '$module/src/actions/$feature/index',
                exportType: 'default',
            };
            return baseInfo;
        }),
        // 输出路径
        output: {
            path: projectPath,
        },
    };
    return options;
}
exports.getDebugLcfConfig = getDebugLcfConfig;
