"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.debug = exports.build = void 0;
const util_1 = require("../util");
const build_1 = require("../service/build");
const meta_1 = require("../service/build/meta");
const config_1 = require("../service/build/config");
const entry_1 = require("../service/build/entry");
const publish_1 = require("../service/publish");
const open_1 = __importDefault(require("open"));
const generate_1 = require("../service/build/generate");
// import { buildMp } from '../service/build/mp'
const toolbox_1 = require("@cloudbase/toolbox");
async function build(cwd = process.cwd()) {
    const buildConfig = (0, config_1.getBuildConfig)(cwd);
    const { name, version, tempPath } = buildConfig;
    // Build for mp raw
    // buildMp()
    (0, util_1.info)('清理 dist 目录 - ' + buildConfig.outputPath);
    await (0, util_1.remove)(buildConfig.outputPath);
    (0, util_1.info)('清理临时入口文件 - ' + tempPath);
    await (0, util_1.remove)(tempPath + '/*');
    await (0, entry_1.writeEntryTempFile)(buildConfig);
    await (0, build_1.runWebpackAsync)((0, config_1.getLibWebpackConfig)(buildConfig));
    const mainLessName = await (0, generate_1.generateLessMergeFile)(buildConfig);
    await (0, meta_1.generateMetaJson)(buildConfig, mainLessName);
    await (0, publish_1.pullMaterialToSourceZip)(cwd, name, version);
    (0, util_1.done)('素材库构建成功');
    (0, util_1.info)(`可将该 build/${name}@${version}.zip 包 WeApps 站点中 [素材管理] 栏目上传或执行命令行 \`wa publish\``);
}
exports.build = build;
async function debug(cwd = process.cwd(), port) {
    // buildMp(true)
    const baseUrl = 'https://lcap.cloud.tencent.com/v2/dev.html';
    const buildConfig = (0, config_1.getBuildConfig)(cwd, 'development');
    (0, util_1.info)('清理 dist 目录');
    await (0, util_1.remove)(buildConfig.outputPath);
    await (0, entry_1.writeEntryTempFile)(buildConfig);
    const after = () => {
        (0, toolbox_1.execWithLoading)(async () => {
            const openUrl = `${baseUrl}?appId=test&mainAppId=test&&detailAppId=tes&source=null&debugPort=${port}&libName=${buildConfig.name}&libVersion=${buildConfig.version}`;
            await (0, open_1.default)(openUrl);
        }, {
            startTip: '组件库 - 打开调试编辑器中',
            successTip: '组件库 - 打开调试编辑器成功',
        });
    };
    await (0, build_1.runDevServer)((0, config_1.getLibWebpackConfig)(buildConfig), port, after);
}
exports.debug = debug;
