"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateLessMergeFile = void 0;
const less_1 = __importDefault(require("less"));
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const util_1 = require("../../util");
const regExpLessImport = /@import.+;/g;
async function generateLessMergeFile(buildConfig) {
    const { lessEntryPath, name, outputPath } = buildConfig;
    if (!fs_extra_1.default.existsSync(lessEntryPath)) {
        return;
    }
    const lessContent = await fs_extra_1.default.readFile(lessEntryPath, {
        encoding: 'utf8',
    });
    const { imports = [] } = await less_1.default.render(lessContent);
    let mergeLessContent = '';
    imports.map((filePath) => {
        if (fs_extra_1.default.existsSync(filePath)) {
            const targetContent = fs_extra_1.default.readFileSync(filePath, {
                encoding: 'utf8',
            });
            mergeLessContent += targetContent.replace(regExpLessImport, '');
        }
    });
    await fs_extra_1.default.remove(lessEntryPath);
    if (mergeLessContent) {
        const md5 = (0, util_1.getMd5)(mergeLessContent);
        const mainLessName = `${name}.main.${md5}.less`;
        const lessDistPath = path_1.default.resolve(outputPath, `./${mainLessName}`);
        await fs_extra_1.default.writeFile(lessDistPath, mergeLessContent, {
            encoding: 'utf8',
        });
        return mainLessName;
    }
}
exports.generateLessMergeFile = generateLessMergeFile;
