"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getIcon = exports.getInfoMap = exports.generateMetaJson = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const camelcase_keys_1 = __importDefault(require("camelcase-keys"));
const util_1 = require("../../util");
async function generateMetaJson(buildConfig, mainLessName) {
    const { manifestPath, outputPath, componentDirPathMap, pluginsDirPathMap, actionsDirPathMap, name, version, title, description, } = buildConfig;
    (0, util_1.info)('生成 meta 文件');
    const metaJsonPath = path_1.default.join(outputPath, './meta.json');
    const manifest = await fs_extra_1.default.readJSON(manifestPath);
    const metaJson = {
        name: name,
        title,
        version,
        desc: description,
        manifest: {
            ...(0, camelcase_keys_1.default)(manifest),
            mainLess: mainLessName,
        },
        components: getInfoMap(componentDirPathMap),
        actions: getInfoMap(actionsDirPathMap),
        plugins: getInfoMap(pluginsDirPathMap),
    };
    await fs_extra_1.default.writeFile(metaJsonPath, JSON.stringify(metaJson, null, 2));
    await fs_extra_1.default.remove(manifestPath);
}
exports.generateMetaJson = generateMetaJson;
function getInfoMap(pathMap) {
    return Object.entries(pathMap).map(([name, entry]) => {
        return {
            name,
            meta: {
                ...fs_extra_1.default.readJSONSync(path_1.default.resolve(entry, './meta.json')),
                icon: getIcon(entry),
            },
        };
    });
}
exports.getInfoMap = getInfoMap;
function getIcon(entry) {
    const extNameMap = {
        svg: 'svg+xml',
        png: 'png',
        jpg: 'jpeg',
        jpeg: 'jpeg',
    };
    return Object.keys(extNameMap)
        .map((extname) => {
        // data:image/svg+xml;base64,
        const iconPath = path_1.default.join(entry, `icon.${extname}`);
        if (fs_extra_1.default.existsSync(iconPath)) {
            const iconBuffer = fs_extra_1.default.readFileSync(iconPath);
            const iconBase64 = iconBuffer.toString('base64');
            return `data:image/${extNameMap[extname]};base64,${iconBase64}`;
        }
        return false;
    })
        .find((i) => i);
}
exports.getIcon = getIcon;
