"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runDevServer = exports.webpackCallback = exports.runWebpackAsync = void 0;
const webpack_1 = __importDefault(require("webpack"));
const webpack_dev_server_3_1 = __importDefault(require("webpack-dev-server-3"));
const util_1 = require("../../util");
async function runWebpackAsync(config) {
    (0, util_1.logWithSpinner)('🚀', '构建 dist 包');
    await new Promise((resolve, reject) => {
        (0, webpack_1.default)(config).run(webpackCallback(resolve, reject));
    });
    (0, util_1.stopSpinner)();
}
exports.runWebpackAsync = runWebpackAsync;
function webpackCallback(resolve, reject) {
    return (err, stats) => {
        var _a;
        if (err) {
            (0, util_1.error)('fatal webpack errors:', (((_a = err.stack) === null || _a === void 0 ? void 0 : _a.toString()) || err.toString()).trim());
            if (err.details) {
                (0, util_1.error)('fatal webpack errors:', err.details.trim());
            }
            reject();
        }
        const info = stats.toJson();
        if (stats.hasErrors()) {
            info.errors.forEach((e) => {
                if (e.trim) {
                    (0, util_1.error)('\n\nWebpack compilation errors:', e.trim());
                }
            });
            return reject();
        }
        return resolve();
    };
}
exports.webpackCallback = webpackCallback;
// eslint-disable-next-line @typescript-eslint/no-empty-function
async function runDevServer(config, port, after = () => { }) {
    return new Promise((resolve) => {
        var _a;
        const compiler = (0, webpack_1.default)(config);
        const devServerOptions = {
            hot: false,
            host: '127.0.0.1',
            contentBase: [(_a = config.output) === null || _a === void 0 ? void 0 : _a.path],
            public: '127.0.0.1:4567',
            headers: {
                'Access-Control-Allow-Origin': '*',
                'Access-Control-Allow-Headers': '*',
            },
            liveReload: true,
            disableHostCheck: true,
            socket: 'socket',
            sockPort: port,
            sockHost: '127.0.0.1',
            after,
        };
        // @ts-expect-error
        webpack_dev_server_3_1.default.addDevServerEntrypoints(config, devServerOptions);
        // @ts-expect-error
        new webpack_dev_server_3_1.default(compiler, devServerOptions).listen(port);
        compiler.hooks.done.tap('IDoNotUnderstandWhatThisStringIsForButItCannotBeEmpty', () => {
            (0, util_1.stopSpinner)();
            resolve();
        });
    });
}
exports.runDevServer = runDevServer;
