"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.pullMaterialToSourceZip = exports.checkDistFileThenBuild = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const util_1 = require("../../util");
const build_1 = require("../../core/build");
async function checkDistFileThenBuild(cwd = process.cwd(), name, version) {
    const zipPath = `build/${name}@${version}.zip`;
    const distMetaJsonPath = path_1.default.join(cwd, zipPath);
    if (!fs_extra_1.default.existsSync(distMetaJsonPath)) {
        (0, util_1.warn)(`暂无发现 ${zipPath} 文件，即将开始构建素材库 build`);
        await (0, build_1.build)(cwd);
    }
}
exports.checkDistFileThenBuild = checkDistFileThenBuild;
async function pullMaterialToSourceZip(cwd = process.cwd(), name, version) {
    const nameVersion = `${name}@${version}`;
    const distPath = path_1.default.join(cwd, 'dist');
    const destPath = path_1.default.join(cwd, 'build', `${nameVersion}.zip`);
    (0, util_1.info)('打包素材库到' + destPath);
    const srcPath = path_1.default.join(cwd, 'src');
    const packageJsonPath = path_1.default.join(cwd, 'package.json');
    await fs_extra_1.default.ensureFile(destPath);
    const [err] = await (0, util_1.promiseWrapper)((0, util_1.compressingZip)([srcPath, packageJsonPath, distPath], destPath));
    if (err) {
        (0, util_1.error)(err);
        process.exit(1);
    }
    return destPath;
}
exports.pullMaterialToSourceZip = pullMaterialToSourceZip;
