"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.publishComps = void 0;
const path = __importStar(require("path"));
const fs = __importStar(require("fs"));
const fse = __importStar(require("fs-extra"));
const toolbox_1 = require("@cloudbase/toolbox");
const config_1 = require("../build/service/build/config");
const common_1 = require("../../common");
const lowcodeService = toolbox_1.CloudApiService.getInstance('lowcode');
const manifestMap = {
    controlJs: 'build/dist/comps.control.js',
    mainJs: 'build/dist/comps.main.js',
    mainCss: 'build/dist/comps.main.css',
    mainLess: 'build/dist/comps.main.less',
};
const sourceFileName = 'source.zip';
const sourceMap = {
    source: 'build/src/source.zip',
};
const compsNameLimit = 32;
class PublishService {
    constructor(meta) {
        this.compsId = meta.id;
        this.compsName = meta.name;
        this.compsPath = meta.path;
        this.compsBuildPath = path.join(this.compsPath, 'build/.publish');
        this.log = meta.log;
        this.pkgVersion = fse.readJsonSync(path.join(__dirname, '../../../package.json')).version;
        (0, common_1.initLowcodeCloudApiEnv)();
    }
    async publish() {
        var _a;
        try {
            // 解压BUILD包
            fs.existsSync(this.compsBuildPath) && (await fse.remove(this.compsBuildPath));
            const { name, version } = (0, config_1.getBuildConfig)(this.compsPath);
            const buildFilePath = path.join(this.compsPath, `./build/${name}@${version}.zip`);
            await (0, toolbox_1.unzipStream)(fs.createReadStream(buildFilePath), this.compsBuildPath);
            // 读取组件库META
            this.meta = await fse.readJson(path.join(this.compsBuildPath, 'dist/meta.json'));
            // 校验组件名
            (_a = this.meta) === null || _a === void 0 ? void 0 : _a.components.forEach((component) => {
                const message = this.isFieldNameInvalid(component.name);
                if (message) {
                    throw new toolbox_1.CloudBaseError(message);
                }
            });
            // 上传组件库
            await this.initPlugin();
            await this.uploadDistFilesToCos();
            await this.uploadSourceZipToCos();
            await this.uploadIconToCos();
        }
        finally {
            // 清除解压内容
            fs.existsSync(this.compsBuildPath) && fse.removeSync(this.compsBuildPath);
        }
    }
    async initPlugin() {
        if (!this.meta) {
            return new toolbox_1.CloudBaseError('没有获取到组件库META消息！');
        }
        this.log.verbose('组件库 - 初始化组件');
        const { actions } = this.meta;
        await lowcodeService.request('UploadComposites', {
            groupName: this.compsName,
            metas: this.meta.components.map((component) => ({
                name: component.name,
                title: component.meta.title,
                description: component.meta.desc,
                category: component.meta.category,
                platform: [],
            })),
            groupContent: {
                actions,
                sourceMap: sourceMap,
                manifestMap: manifestMap,
            },
        });
    }
    async uploadDistFilesToCos() {
        if (!this.meta) {
            return new toolbox_1.CloudBaseError('没有获取到组件库META消息！');
        }
        this.log.verbose('组件库 - 上传DIST');
        const { manifest } = this.meta;
        const fileMetas = Object.keys(manifest).map((key) => {
            const fileName = manifest[key];
            const filePath = path.join(this.compsBuildPath, 'dist', fileName);
            const fileContent = fs.readFileSync(filePath);
            return {
                fileName: manifestMap[key],
                fileContent,
            };
        });
        const res = await lowcodeService.request('ListCompositeGroupPublicFileAuthorization', {
            comGroupId: this.compsId,
            files: fileMetas.map((meta) => ({
                fileName: meta.fileName,
                contentLength: meta.fileContent.length,
            })),
        });
        const tokens = res.data;
        await Promise.all(tokens.map((token) => {
            const { fileContent } = fileMetas.find(({ fileName }) => fileName === token.id) || {};
            return this.uploadFileToCos(token, fileContent);
        }));
    }
    async uploadSourceZipToCos() {
        if (!this.meta) {
            return new toolbox_1.CloudBaseError('没有获取到组件库META消息！');
        }
        this.log.verbose('组件库 - 上传SRC');
        // 压缩源码
        const { name, version } = (0, config_1.getBuildConfig)(this.compsPath);
        const zippedFilePath = path.join(this.compsPath, `./build/${name}@${version}.zip`);
        // 上传源码
        const fileContent = fs.readFileSync(zippedFilePath);
        const fileMeta = {
            fileName: sourceMap['source'],
            contentLength: fileContent.length,
            headers: {
                'x-cos-meta-cli-version': this.pkgVersion,
            },
        };
        const res = await lowcodeService.request('ListCompositeGroupPrivateFileAuthorization', {
            comGroupId: this.compsId,
            files: [fileMeta],
        });
        const tokens = res.data;
        const token = tokens[0];
        await this.uploadFileToCos(token, fileContent);
    }
    async uploadIconToCos() {
        if (!this.meta) {
            return new toolbox_1.CloudBaseError('没有获取到组件库META消息！');
        }
        this.log.verbose('组件库 - 上传ICON');
        // 收集Icon
        const icons = this.meta.components
            .filter((component) => {
            const iconPath = path.join(this.compsBuildPath, 'src/components', component.name, 'icon.svg');
            return fs.existsSync(iconPath);
        })
            .map((component) => {
            const iconPath = path.join(this.compsBuildPath, 'src/components', component.name, 'icon.svg');
            return {
                name: `build/meta/${component.name}/icon.svg`,
                content: fs.readFileSync(iconPath),
            };
        });
        // 上传Icon
        const res = await lowcodeService.request('ListCompositeGroupPublicFileAuthorization', {
            comGroupId: this.compsId,
            files: icons.map((icon) => {
                var _a;
                return ({
                    fileName: icon.name,
                    contentLength: (_a = icon.content) === null || _a === void 0 ? void 0 : _a.length,
                });
            }),
        });
        const tokens = res.data;
        await Promise.all(tokens.map((token) => {
            const { content } = icons.find((icon) => icon.name === token.id) || {};
            return this.uploadFileToCos(token, content);
        }));
        // 更新Icon地址
        const metas = this.meta.components.map((component) => {
            var _a;
            return ({
                name: component.name,
                title: component.meta.title,
                description: component.meta.desc,
                category: component.meta.category,
                platform: [],
                icon: (_a = tokens.find((token) => token.id.includes(component.name))) === null || _a === void 0 ? void 0 : _a.url,
            });
        });
        await lowcodeService.request('UploadComposites', {
            groupName: this.compsName,
            metas,
        });
    }
    uploadFileToCos(token, fileContent) {
        return (0, toolbox_1.putFetch)(token.url, {
            headers: {
                'content-length': String(fileContent.length),
                'x-cos-security-token': token.sessionToken,
                'x-cos-meta-cli-version': this.pkgVersion,
                Authorization: token.authorization,
            },
            body: fileContent,
        });
    }
    isFieldNameInvalid(name) {
        let message = null;
        if (!name) {
            message = '组件名不能为空';
        }
        else if (name.length > compsNameLimit) {
            message = `组件名长度超过了${compsNameLimit}: ${name}`;
        }
        else if (/[^a-zA-Z0-9_]/gi.test(name)) {
            message = `组件名只能包含字母、数字或下划线: ${name}`;
        }
        else if (/^[0-9]/.test(name)) {
            message = `组件名不能以数字开头: ${name}`;
        }
        return message;
    }
}
async function publishComps(info) {
    const service = new PublishService(info);
    await service.publish();
}
exports.publishComps = publishComps;
